
if (!require(raster)) install.packages("raster")
require(raster)
if (!require(sp)) install.packages("sp")
require(sp)
if (!require(data.table)) install.packages("data.table")
require(data.table)
if (!require(truncdist)) install.packages("truncdist")
require(truncdist)


#### load datasets #### 

# volume dynamics data (TmFO)
volDynData <- read.csv("volDynData.csv",  stringsAsFactors = F)
# TmFO plots info (coordinates, year of logging, etc)
plotInfo <- read.csv("plotInfo.csv",  stringsAsFactors = F)
# RadamBrasil volume data
volRadam <- read.csv("volRadam.csv",  stringsAsFactors = F)


#### load parameters posterior ####
paramsDam = read.csv("paramsDam.csv")
paramsVolDyn = read.csv("paramsVolDyn.csv")
paramsVolDynSite = read.csv("paramsVolDynSite.csv")
paramsPropRecru = read.csv("paramsPropRecru.csv")

#### load maps and spatially explicit variables ####

# spatially explicit variables from FORMIND
paramsFormind = read.csv("paramsFormind.csv")

# area available for logging
grd <- read.csv("spatVariables.csv", stringsAsFactors = F)
coordinates(grd) <- ~ longitude+latitude
gridded(grd) <- TRUE
proj4string(grd) <- CRS("+proj=longlat")

## total area of pixels (in km2)
areaTot <- raster::extract(area(raster(grd)), grd)
## total area available for logging (in ha)
grd$areaLogging <- areaTot*grd$pAreaLogging*100  ## km2 -> ha

# TmFO sites coordinates on the 1° grid
siteCoords <- unique(plotInfo[,c("site","longitude","latitude")])
siteCoords$longitude <- floor(siteCoords$longitude) + 0.5
siteCoords$latitude <- floor(siteCoords$latitude) + 0.5

#### source other R scripts #### 

source("functions.R")

source("kriging.R")

source("predictionsFirstHarvest.R")


## Clear environment ## 
rm(list=setdiff(ls(), "predictions"))

#### Figure 1 ####

## summary statistics ##
# only for TmFO sites
# inf: lower bound of the 95% credibility interval 
# med: median
# sup: upper bound of the 95% credibility interval 

ICvrec = subset(predictions, site != "amazonia")[,.(inf = quantile(pvrec,0.025),
                                                    med = quantile(pvrec,0.5),
                                                    sup = quantile(pvrec,0.975)),
                                                 .(site,vext,omega0,trot)]

# order sites by proportion of locally harvested volume, from lowest to highest
ICvrec$ns = as.numeric(as.factor(as.character(ICvrec$site)))
order_ns <- unique(ICvrec[order(ICvrec$omega0),c("ns","omega0")])$ns
dt_order <- data.table(order=1:15, ns = order_ns)
ICvrec = merge(ICvrec,dt_order,by="ns")
order_sites <- unique(ICvrec[order(ICvrec$omega0),c("site","omega0")])$site
order_om0 <- sort(unique(ICvrec$omega0))

if (!require(RColorBrewer)) install.packages("RColorBrewer")
require(RColorBrewer)
cols <- c("#000000","#7FFFD4","#8B008B",brewer.pal(12,"Paired")[-11],"#FFD700")

layout(matrix(c(rep(1:2,2),3,3),nrow=2))
par(mar=c(4,4,1,1))

# graph 1 - recovery = f(vext)
dat = subset(ICvrec, trot==30)
# x axis
dat$vext2 = as.numeric(as.factor(dat$vext)) + 0.03*dat$order - 0.03*7.5
plot(x=dat$vext2, y=dat$med*100, col=cols[dat$order], pch=16, ylim=c(0,max(dat$sup*100)), ylab="Volume recovery (%)", xlab="",xaxt="n")
axis(1, at=c(1,2,3), labels=c("10","20","30"))
mtext(outer=F,side=1,expression("Logging intensity ("*m^3*ha^{-1}*")"),line=2.5,cex=0.8)
segments(x0 = dat$vext2, y0=dat$inf*100, y1=dat$sup*100, col=cols[dat$order])
abline(100,0,lty=2)
legend("top",legend="Cutting cycle: 30 yr", bty = "n"); legend("topleft",legend="(a)",bty = "n")

# graph 2 - recovery = f(trot)
dat = subset(ICvrec, vext==20)
# x axis
dat$trot2 = as.numeric(as.factor(dat$trot)) + 0.03*dat$order - (0.03*7.5)
plot(x=dat$trot2, y=dat$med*100, col=cols[dat$order], pch=16, ylim=c(0,max(dat$sup*100)), ylab="Volume recovery (%)", xlab="", xaxt="n")
axis(side=1, at = 1:3,labels = c("15","30","65"))
mtext(outer=F,side=1,"Cutting cycle (yr)",line=2.5,cex=0.8)
segments(x0 = dat$trot2, y0=dat$inf*100, y1=dat$sup*100, col=cols[dat$order])
abline(100,0,lty=2)
legend("top",legend=expression("Logging intensity: 20 "*m^3*ha^{-1}),bty = "n"); legend("topleft",legend="(b)",bty = "n")

# legend
par(mar=c(0,0,0,0))
plot.new()
legend(x="center",legend = paste(order_sites ," : ",round(order_om0*100),"%",sep=""), col=cols, pch=16, title = "(d) % of volume in harvested species")



#### Figure 2 ####

if (!require(ggplot2)) install.packages("ggplot2")
library(ggplot2)
if (!require(ggpubr)) install.packages("ggpubr")
library(ggpubr)

## summary statistics ##
ICvrec = predictions[site == "amazonia",.(inf = quantile(pvrec,0.025),
                                          med = quantile(pvrec,0.5),
                                          sup = quantile(pvrec,0.975)),
                     .(vext, omega0, trot, longitude, latitude)]
ICvrec$med[ICvrec$med>1] <- 1
ICvrec$med <- ICvrec$med*100 
ICvrec$scenario <- factor(paste(ICvrec$vext, ICvrec$trot), levels = c("20 30", "10 30", "30 30", "20 15", "20 65"), labels = c("(a) Standard practices","(b) Low intensity","(c) High intensity","(d) Short cycle","(e) Long cycle"))


g1 <- ggplot(subset(ICvrec,vext==20 & trot ==30), aes(x=longitude,y=latitude,fill=med)) +
  geom_raster() + theme_bw() +  facet_wrap(~scenario) + 
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_blank(),
        panel.border = element_rect(colour = "black"),
        legend.position = "bottom") + 
  guides(fill=guide_colourbar(title.position="bottom", barwidth=10)) +
  labs (x = "", y = "") + coord_fixed() + 
  scale_fill_gradientn(colours = c("red","orange","yellow","forestgreen"), 
                       limits=c(0,100), name = "Volume recovery (%)")

g2 <- ggplot(subset(ICvrec,vext!=20 & trot ==30), aes(x=longitude,y=latitude,fill=med)) +
  geom_raster() + theme_bw() +  facet_wrap(~scenario, nrow=2) + 
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_blank(),
        panel.border = element_rect(colour = "black"),
        legend.position = "none") + 
  labs (x = "", y = "") + coord_fixed() + 
  scale_fill_gradientn(colours = c("red","orange","yellow","forestgreen"), limits=c(0,100))

g3 <- ggplot(subset(ICvrec,vext==20 & trot !=30), aes(x=longitude,y=latitude,fill=med)) +
  geom_raster() + theme_bw() +  facet_wrap(~scenario, nrow=2) + 
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_blank(),
        panel.border = element_rect(colour = "black"),
        legend.position = "none") + 
  labs (x = "", y = "") + coord_fixed() + 
  scale_fill_gradientn(colours = c("red","orange","yellow","forestgreen"), limits=c(0,100))

ggarrange(g1,g2,g3, ncol=3)


#### Figure 3 ####

## Clear environment ## 
rm(list=setdiff(ls(), "predictions"))

## simulation time: 300 years
tsim <- 300
source("predictionsTrajectory.R")

## change factor levels to create labels for plots 
IC_traj$variable <- factor(IC_traj$variable, levels = c("vtot","vext","vrec"), 
                           labels = c(vtot = expression("Potential timber (M"*m^3*")"), 
                                      vext = expression("Extracted timber (M"*m^3*yr^{-1}*")"),
                                      vrec = expression("Timber recovery (M"*m^3*yr^{-1}*")")))
IC_traj$scenario <- as.factor(IC_traj$scenario)
levels(IC_traj$scenario) <- c("Low intensity","Short cycle","Standard practices","Long cycle","High intensity")
IC_traj$scenario <- factor(IC_traj$scenario,levels = c(levels(IC_traj$scenario)[3], "", levels(IC_traj$scenario)[c(1,5,2,4)]))

### sawlog demand data ###
## current timber production from Lentini et al 2005
sawlog_demand <- 34*1e6
## predictions of sawnwood consumption increase 2006 -> 2060 from buongiorno et al 2012 
df_demand <- data.frame(matrix(rep(c(1, range(c(39.1,33.1,36.2,42.3)/32.5)) * sawlog_demand*1e-6, 2),byrow=T,nrow=2))
colnames(df_demand) <- c("current","min_future","max_future")
df_demand$variable = factor(c("vext","vrec"), labels = c(vext = expression("Extracted timber (M"*m^3*yr^{-1}*")"),  vrec = expression("Timber recovery (M"*m^3*yr^{-1}*")"))) 

data.annotate <- data.frame(lab = paste("(", letters[c(3,1,2)],")", sep=""), x = -Inf, y = Inf,
                            variable = factor(c("vtot","vext","vrec"), 
                                              labels = c(vtot = expression("Potential timber (M"*m^3*")"), 
                                                         vext = expression("Extracted timber (M"*m^3*yr^{-1}*")"),
                                                         vrec = expression("Timber recovery (M"*m^3*yr^{-1}*")"))))

### colours ###
col_palette = c(RColorBrewer::brewer.pal(name = "Set1", n=5)[1],"white",RColorBrewer::brewer.pal(name = "Set1", n=5)[2:5])

### plots ###
p <- ggplot(subset(IC_traj, variable!="vrec"),aes(x=t, y = med, fill=scenario)) + 
  geom_hline(data = df_demand, aes(yintercept = current), lty=3, lwd=0.5) + 
  geom_rect(data = df_demand, aes(xmin=-Inf, xmax = +Inf, ymin = min_future, ymax = max_future), alpha=0.1, inherit.aes = FALSE) +
  geom_ribbon(aes(ymin=inf,ymax=sup),alpha=0.1, colour=NA, show.legend = F) +
  geom_line(aes(colour=scenario)) + 
  labs(x = "Time since first logging event (yrs)", y = NULL) +
  geom_text(data = data.annotate, aes(label = lab, x = x, y = y), hjust = -0.2, vjust = 1.5, inherit.aes = FALSE) +
  scale_colour_manual(values = col_palette, drop=FALSE) + scale_fill_brewer(palette = "Set1") +
  facet_wrap( ~ variable, scales = "free_y", ncol=1, strip.position = "left", 
              labeller = label_parsed) + 
  theme_bw() + theme(panel.grid.major = element_blank(),
                     panel.grid.minor = element_blank(), 
                     panel.border = element_rect(colour = "black"),
                     strip.background = element_blank(),
                     strip.placement = "outside", 
                     legend.position="top", 
                     legend.title = element_blank()) + 
  guides(colour=guide_legend(ncol=3,byrow=F))
p

## Clear environment ## 
rm(list=setdiff(ls(), "predicAm"))
source("functions.R")


#### Figure 4  ####

futureVol <- predicAm[vext==20 & trot==30, 
                      c("iter","longitude","latitude",
                        "t0","aG","aM","betaG","betaM",
                        "theta","area","pdef")]

dt <- data.table(expand.grid(iter = unique(predicAm$iter),
                             longitude = seq(from=-79.5, to=-44.5, by=1),
                             latitude = seq(from=-19.5, to=9.5, by=1), 
                             paM = seq(0.05,0.45,0.05),  # relative increase in annual volume mortality
                             pt0 = seq(0.05,0.45,0.05))) # relative decrease in maturity
futureVol <- merge(futureVol,dt, by=c("iter","longitude","latitude"))

futureVol$aMb <- futureVol$aM*(1+futureVol$paM)
# maximum annual volume mortality (aM) must stay lower than maximum annual volume gain (aG) 
futureVol$aMb[futureVol$aMb>futureVol$aG] <- futureVol$aG[futureVol$aMb>futureVol$aG]

futureVol <- futureVol[,.(Vol=sum(volume(t=t0*(1-pt0), ag=aG, am=aMb,    
                                         bg=betaG,bm=betaM, th=theta, pdef = pdef)*area*1e-6),   ## volume
                          dV = sum(volume(t=t0*(1-pt0), ag=aG, am=aMb, 
                                          bg=betaG,bm=betaM, th=theta, pdef = pdef)*area*1e-6) - 
                            sum(volume(t=t0*(1-pt0)-1, ag=aG, am=aMb,                                ## volume change
                                       bg=betaG,bm=betaM, th=theta, pdef = pdef)*area*1e-6)),
                       .(iter,paM,pt0)]

### summary statistics ###
DT <- melt(futureVol, measure.vars = c("Vol","dV"))
DT <- DT[,.(inf = quantile(value, 0.025),
            med = quantile(value, 0.5),
            sup = quantile(value, 0.975)),
         .(paM,pt0,variable)]

g1 <- ggplot(data=subset(DT,variable == "Vol"), aes(x=paM*100, y=pt0*100)) + 
  geom_raster(aes(fill=med)) + 
  scale_fill_gradientn(colours = rev(terrain.colors(6))) + 
  labs(x="Increase in volume mortality (%)", y="Increase in disturbance (%)",fill="",
       title = expression("(a) Timber volume (M"*m^3*")")) +
  theme_classic() + theme(plot.title = element_text(size=12))
g2 <- ggplot(data=subset(DT,variable == "dV"), aes(x=paM*100, y=pt0*100)) + 
  geom_raster(aes(fill=med)) + 
  scale_fill_gradientn(colours = rev(heat.colors(6))) + 
  labs(x="Increase in volume mortality (%)", y="Increase in disturbance (%)",fill="",
       title = expression("(b) Timber productivity "*"(M"*m^3*yr^{-1}*")")) + 
  theme_classic() + theme(plot.title = element_text(size=12))

ggarrange(g1,g2)
