
#### make predictions ####

# sample 100 sets of parameters 
samp_iter <- c(0,sample(min(nrow(paramsDam),nrow(paramsVolDyn),nrow(paramsPropRecru)), 100))

# make 5 scenarios with varying logging intensity (vext) and cutting cycle (trot)
# sample all pixels in Amazonia (figure 2), and all TmFO sites within those pixels (figure 1)
predictions <- data.table(expand.grid(iter = samp_iter,
                                      vext = c(10,20,30), 
                                      trot = c(15,30,65), 
                                      site = "amazonia", 
                                      longitude = seq(from=-79.5, to=-44.5, by=1),
                                      latitude=seq(from=-19.5, to=9.5, by=1),
                                      stringsAsFactors = F))
predictions_sites <- data.table(expand.grid(iter = samp_iter,
                                            vext = c(10,20,30), 
                                            trot = c(15,30,65), 
                                            site = siteCoords$site,
                                            stringsAsFactors = F))
## add and round TmFO sites' coordinates (to a 1° grid)
predictions_sites <- merge(predictions_sites, siteCoords, by="site")
predictions_sites[,longitude := floor(longitude) + 0.5]
predictions_sites[,latitude := floor(latitude) + 0.5]

predictions <- rbind(predictions, predictions_sites)
predictions <- subset(predictions, vext==20 | trot == 30)
setkey(predictions)

### add parameters values ###

predictions <- merge(predictions, paramsDam, by="iter")
predictions <- merge(predictions, paramsVolDyn, by="iter")
predictions <- merge(predictions, paramsPropRecru, by="iter")

# sample sites for site specific parameters
predictions$samp_site <- predictions$site
predictions$site[predictions$site=="amazonia"] <- sample(as.character(siteCoords$site), sum(predictions$site=="amazonia"), replace = TRUE)
predictions <- merge(predictions, paramsVolDynSite, by= c("iter","site"))
predictions$site <- predictions$samp_site
predictions$samp_site <- NULL

# add spatially explicit variables
predictions <- merge(predictions, grd, by=c("longitude","latitude"))

## add stem mortality and initial proprotion of timber volume
logistic <- function(x) 1/(1+exp(-x))
predictions$omega0 <- logistic(rnorm(nrow(predictions), 
                               mean = predictions$mean_logit_om, 
                               sd = sqrt(predictions$var_logit_om)))
predictions$stem_mort <- logistic(rnorm(nrow(predictions), 
                                     mean = predictions$mean_logit_mort, 
                                     sd = sqrt(predictions$var_logit_mort)))

## sample values from Formind simulations (aG and Vclimax)
paramsFormind = data.table(paramsFormind)
paramsFormind[,iter := unique(predictions$iter),.(longitude,latitude)]
predictions = merge(predictions, paramsFormind, by=c("iter","longitude","latitude"))

# for TmFO sites: change proportion of timber to locally harvested species and spatial variables to their local value
predictions <- merge(predictions, unique(plotInfo[,c("site","omegaLoc","aGLoc","vclimaxLoc","stem_mortLoc")]), by="site",all=TRUE)
#omega0
predictions$omega0[predictions$site!="amazonia"] <- predictions$omegaLoc[predictions$site!="amazonia"]
predictions$omegaLoc <- NULL
# aG
predictions$aG[predictions$site!="amazonia"] <- predictions$aGLoc[predictions$site!="amazonia"]
predictions$aGLoc <- NULL
# vclimax
predictions$vclimax[predictions$site!="amazonia"] <- predictions$vclimaxLoc[predictions$site!="amazonia"]
predictions$vclimaxLoc <- NULL
# stem_mort
predictions$stem_mort[predictions$site!="amazonia"] <- predictions$stem_mortLoc[predictions$site!="amazonia"]
predictions$stem_mortLoc <- NULL


# add the proportion of defective stems 
predictions <- merge(predictions, data.table(iter=samp_iter, pdef = rbeta(length(samp_iter), 6,14)), by="iter")


# calculate intermediate parameters
predictions$t0 <- (1/predictions$stem_mort)^(predictions$lambda)*(1-predictions$dti)
predictions$vmax <- sapply(1:nrow(predictions), function(i) rtrunc(1, spec="norm", a = 50, b=predictions$aG[i]/predictions$theta[i], mean=predictions$vclimax[i], sd = predictions$sigmaVmax[i])*(1-predictions$pdef[i]) )
predictions$aM <- predictions$aG - predictions$theta*predictions$vmax
# error on V: per pixel (all areas inside one pixel are 100% dependent and pixels are independent -> compromise)
predictions$errV <- rnorm(nrow(predictions), 0, predictions$sigmaV)

# initial volume and potential timber volume/local timber volume (when site from TmFO)
predictions$V0 <- volume(predictions$t0, predictions$aG, predictions$aM, predictions$betaG, predictions$betaM, predictions$theta, pdef = predictions$pdef)
predictions$Vtimb0 <- predictions$V0*predictions$omega0

# extracted volume for each scenario (minimum of what is wanted: vext, and what is available: Vtimb0)
predictions$vextReal <- apply(predictions[,c("vext","Vtimb0")],1,min)

# deltaV: total volume loss
predictions$deltaV <- deltaVPrediction(V0=predictions$V0, Vext=predictions$vextReal, om0=predictions$omega0, rho=predictions$psi, e=predictions$e)

# t1: post-logging maturity
dt1 <- predictions[,.(t1 = t0Prediction(t0=t0, deltaV=deltaV, aG=aG, aM=aM, bG=betaG, bM=betaM, theta=theta, pdef=pdef)), .(iter,longitude,latitude,vext,trot,site)]
predictions <- merge(predictions, dt1, by=c("iter","longitude","latitude","vext","trot","site"))

# om1: post-logging proprotion of timber volume
predictions$om1 <- (predictions$omega0*predictions$V0-predictions$vextReal)/(predictions$V0-predictions$deltaV)
# predictions$om1[predictions$V0==predictions$deltaV] <- predictions$omega0

# om2: proportion of timber volume at the end of the cutting cycle, after recovery from recruitment
DTom2 <- predictions[,.(om2 = omega_t(tvec=c(t1+trot), t1, om1, omega0, aG, aM, betaG, betaM, theta, intercept, slope)),.(vext,trot,longitude,latitude,iter,site)]
predictions <- merge(predictions, DTom2, by=c("vext","trot","longitude","latitude","iter","site"))

# vrec: timber volume recovered
predictions$vrec <- volume(t=predictions$t1+predictions$trot, 
                          ag=predictions$aG,  am=predictions$aM, 
                          bg=predictions$betaG, bm=predictions$betaM, 
                          th=predictions$theta, pdef=predictions$pdef) * predictions$om2 - 
  (predictions$V0 - predictions$deltaV)*predictions$om1
predictions$pvrec <- predictions$vrec/predictions$vextReal
